@@ -50,6 +50,18 @@ from global_chem.organic_synthesis.solvents.common_organic_solvents import Commo
 from global_chem.organic_synthesis.protecting_groups.amino_acid_protecting_groups import AminoAcidProtectingGroups
 from global_chem.organic_synthesis.bidendate_phosphine_ligands.nickel_ligands import NickelBidendatePhosphineLigands
 
+# Food
+
+from global_chem.food.salt.salt import Salt
+from global_chem.food.color_additives.fda_list_one import FDAListOne
+from global_chem.food.color_additives.fda_list_two import FDAListTwo
+from global_chem.food.color_additives.fda_list_three import FDAListThree
+from global_chem.food.color_additives.fda_list_four import FDAListFour
+from global_chem.food.color_additives.fda_list_five import FDAListFive
+from global_chem.food.color_additives.fda_list_six import FDAListSix
+from global_chem.food.color_additives.fda_list_seven import FDAListSeven
+
+
 # Narcotics
 
 from global_chem.narcotics.schedule_one import ScheduleOne
@@ -77,6 +89,7 @@ from global_chem.miscellaneous.regex_patterns import CommonRegexPatterns
 # Sex
 
 from global_chem.sex.exsens.lube import Lube
+from global_chem.sex.exsens.products import ExsensProducts
 from global_chem.sex.tainted_sexual_enhancement.tainted_sexual_enhancement import TaintedSexualEnhancements
 
 from global_chem.global_chem import GlobalChem
